#
# spec file for package python-WebOb
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-WebOb
Version:        1.4
Release:        42.1
Summary:        WSGI request and response object
License:        MIT
Group:          Development/Languages/Python
Url:            http://webob.org/
Source:         http://pypi.python.org/packages/source/W/WebOb/WebOb-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Test requirements:
# for ssl module:
BuildRequires:  python
BuildRequires:  python-nose
# Documentation requirements:
BuildRequires:  python-Sphinx
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       python-webob = %{version}
Obsoletes:      python-webob < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
WebOb provides wrappers around the WSGI request environment, and an
object to help create WSGI responses.

The objects map much of the specified behavior of HTTP, including
header parsing and accessors for other standard parts of the
environment.

%package doc
Summary:        WSGI request and response object - Documentation
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n WebOb-%{version}

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py test

%files
%defattr(-,root,root,-)
%doc docs/license.txt
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc build/sphinx/html

%changelog
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 1.4:
  * Remove ``webob.__version__``, the version number had not been kept in sync
    with the official pkg version.  To obtain the WebOb version number, use
    ``pkg_resources.get_distribution('webob').version`` instead.
  * Fix a bug in ``EmptyResponse`` that prevents it from setting self.close as
    appropriate due to testing truthiness of object rather than if it is
    something other than ``None``.
  * Fix a bug in ``SignedSerializer`` preventing secrets from containing
    higher-order characters. See https://github.com/Pylons/webob/issues/136
  * Use the ``hmac.compare_digest`` method when available for constant-time
    comparisons.
  * Fix a bug in ``SignedCookieProfile`` whereby we didn't keep the original
    serializer around, this would cause us to have ``SignedSerializer`` be added
    on top of a ``SignedSerializer`` which would cause it to be run twice when
    attempting to verify a cookie.  See https://github.com/Pylons/webob/pull/127
  * Backwards Incompatible change: When ``CookieProfile.get_value`` and
    ``SignedCookieProfile.get_value`` fails to deserialize a badly encoded
    value, we now return ``None`` as if the cookie was never set in the first
    place instead of allowing a ``ValueError`` to be raised to the calling code.
    See https://github.com/Pylons/webob/pull/126
  * Added a read-only ``domain`` property to ``BaseRequest``.  This property
    returns the domain portion of the host value.  For example, if the
    environment contains an ``HTTP_HOST`` value of ``foo.example.com:8000``,
    ``request.domain`` will return ``foo.example.com``.
  * Added five new APIs: ``webob.cookies.CookieProfile``,
    ``webob.cookies.SignedCookieProfile``, ``webob.cookies.JSONSerializer`` and
    ``webob.cookies.SignedSerializer``, and ``webob.cookies.make_cookie``. These
    APIs are convenience APIs for generating and parsing cookie headers as well
    as dealing with signing cookies.
  * Cookies generated via webob.cookies quoted characters in cookie values that
    did not need to be quoted per RFC 6265.  The following characters are no
    longer quoted in cookie values: ``~/=<>()[]{}?@`` .  The full set of
    non-letter-or-digit unquoted cookie value characters is now
    ``!#$%%&'*+-.^_`|~/: =<>()[]{}?@``.  See
    http://tools.ietf.org/html/rfc6265#section-4.1.1 for more information.
  * Cookie names are now restricted to the set of characters expected by RFC
    6265.  Previously they could contain unsupported characters such as ``/``.
  * Older versions of Webob escaped the doublequote to ``\"`` and the backslash
    to ``\\`` when quoting cookie values.  Now, instead, cookie serialization
    generates ``\042`` for the doublequote and ``\134`` for the backslash. This
    is what is expected as per RFC 6265.  Note that old cookie values that do
    have the older style quoting in them will still be unquoted correctly,
    however.
  * Added support for draft status code 451 ("Unavailable for Legal Reasons").
    See http://tools.ietf.org/html/draft-tbray-http-legally-restricted-status-00
  * Added status codes 428, 429, 431 and 511 to ``util.status_reasons`` (they
    were already present in a previous release as ``webob.exc`` exceptions).
  * MIMEAccept happily parsed malformed wildcard strings like "image/pn*" at
    parse time, but then threw an AssertionError during matching.  See
    https://github.com/Pylons/webob/pull/83 .
  * Preserve document ordering of GET and POST request data when POST data
    passed to Request.blank is a MultiDict.
    See https://github.com/Pylons/webob/pull/96
  * Allow query strings attached to PATCH requests to populate request.params.
    See https://github.com/Pylons/webob/pull/106
  * Added Python 3.3 trove classifier.
* Tue Feb 18 2014 ro@suse.de
- added license.txt as doc file
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Mar 27 2013 speilicke@suse.com
- BuildRequire python (for ssl module) and drop pyOpenSSL
* Mon Jan 14 2013 saschpe@suse.de
- (Build)Require python-pyOpenSSL instead of M2Crypto (to get the
  ssl Python base module)
* Fri Nov 23 2012 saschpe@suse.de
- Add dependency on python-M2Crypto, otherwise you won't get HTTPS
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 1.2.3:
  + Fix parsing of form submissions where fields have transfer-content-encoding headers.
- Build HTML documentation
- Run testsuite
- Split of doc package
* Sat Sep 22 2012 os-dev@jacraig.com
- Update to 1.2.2:
  * Fix multiple calls to ``cache_expires()`` not fully overriding the
    previously set headers.
  * Fix parsing of form submissions where fields have different encodings.
- Many changes between versions 1.1.1 and 1.2.1.  Please see docs/news.txt
  for full details.  Major changes include support for only Python 3.2, 2.7,
  2.6.
- Removed dependency on python-Tempita and python-wsgiproxy: these are only
  used in example code in the documentation and not actual runtime reqs.
- Removed dependency on python-nose: it is only needed to run tests.
- Removed dependency on python-WebTest: it was removed as a testing
  requirement in 1.2a1.
* Mon Nov 28 2011 prusnak@opensuse.org
- spec cleanup
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 1.1.1:
  * Fix disconnect detection being incorrect in some cases
  * Fix exception when calling .accept.best_match(..) on a header containing
    '*' (instead of '*/*')
  * Split Accept class into appropriate subclasses (AcceptCharset,
    AcceptLanguage)
  * Improve language matching code so that 'en' in AcceptLanguage('en-gb')
    (the app can now offer a generic 'en' and it will match any of the
    accepted dialects) and 'en_GB' in AcceptLanguage('en-gb') (normalization
    of the dash/underscode in language names).
  * Deprecate req.etag.weak_match(..)
  * Deprecate Response.request and Response.environ attrs.
* Thu Sep  1 2011 saschpe@suse.de
- Initial version
